# cima h commutations factors
## This package aim to provide commutations factors computed based on CIMA H table for actuarials projects
## The current commutations factors list are:
* lx: Number of survivors at age x according to the mortability table 
* dx: Number of death at age x according to the mortability table
* W: The age where there is no survivors according the MT
* qx: Death probality betwwen age x and x+1
* Cx: Present value of survivor numbers
* Dx: 
* Mx:
* Rx:
* Sx:
* Nx:
* A_k:  Certain present value for a annuity of 1F payable in advance over k years
* A_xn: Probable present value at age x over n years
* nEx: Deferred capital at age x over n years
